function dcm = quatToDcm(q, convention)
arguments
    q           (1, :)
    convention  {mustBeMember(convention, {'scalar_first', 'scalar_last'})} = 'scalar_first'
end
% quatToDcm - This function converts quaternion to direction cosine
%             martrix (dcm).
% 
% INPUTS:
%         - q, double [4,1], quaternion.
% 
% OUTPUTS:
%         - dcm, double [3,3], direction cosine matrix.
% 
% CALLED FUNCTIONS: -
% 
% REVISIONS:
% -
% Copyright © 2021, Skyward Experimental Rocketry, AFD department
% All rights reserved
% 
% SPDX-License-Identifier: GPL-3.0-or-later


switch convention
    case 'scalar_first'
        qw = q(1);
        qx = q(2); qy = q(3); qz = q(4);
    case 'scalar_last'
        qw = q(4);
        qx = q(1); qy = q(2); qz = q(3);
end

dcm = zeros(3);

dcm(1, 1) = qw^2 + qx^2 - qy^2 - qz^2;
dcm(1, 2) = 2*(qx*qy + qw*qz);
dcm(1, 3) = 2*(qx*qz - qw*qy);
dcm(2, 1) = 2*(qx*qy - qw*qz);
dcm(2, 2) = qw^2 - qx^2 + qy^2 - qz^2;
dcm(2, 3) = 2*(qy*qz + qw*qx);
dcm(3, 1) = 2*(qx*qz + qw*qy);
dcm(3, 2) = 2*(qy*qz - qw*qx);
dcm(3, 3) = qw^2 - qx^2 - qy^2 + qz^2;