function delay = delayControl(rocket)
arguments
    rocket      Rocket
end
%{ 

delayCOntrol - This function calculates the delay to change airbrakes
               configuration, basing on servo motor angular velocity.

INTPUTS: 
            - pControl, double [1 x n° configurations changes], airbrakes configurations;
            - settings, struct, rocket and simulation data.

OUTPUTS:
            - delay, double [1 x n° configurations changes], delay time vector.

CALLED FUNCTIONS: -

REVISIONS:
- 0     03/10/2021, Release,   Davide Rosato
Copyright © 2021, Skyward Experimental Rocketry, AFD department
All rights reserved

SPDX-License-Identifier: GPL-3.0-or-later

%}

A = -9.43386/(3*1000);
B = 19.86779/(3*1000);
alpha = @(S) (-B + sqrt(B^2 + 4*A*S))/(2*A);

% settings.hprot = rocket.airbrakes.height
% settings.wprot = rocket.airbrakes.width
% pControl = rocket.airbrakes.extension
% settings.vServo = rocket.airbrakes.servoOmega
controlSurf = rocket.airbrakes.height(rocket.airbrakes.extension) * rocket.airbrakes.width;

servoAngle = alpha(controlSurf);

Np = length(rocket.airbrakes.extension);
delay = zeros(1, Np-1);

for i = 2:Np
    delay(i-1) = abs(servoAngle(i) - servoAngle(i-1))/rocket.airbrakes.servoOmega;
end

end